@@ -7,17 +7,33 @@ using namespace Rcpp ;
 
 
 // constant model
-void tp1(arma::mat& g3, int lk, double gam, double om) {
-    int Nmin=0;
-    for(int n1=0; n1<lk; n1++) {
-	for(int n2=0; n2<lk; n2++) {
-	    Nmin = std::min(n1, n2);
-	    for(int c=0; c<=Nmin; c++) {
-		g3.at(n1, n2) += exp(Rf_dbinom(c, n1, om, true) +
-				  Rf_dpois(n2-c, gam, true));
-	    }
-	}
+//void tp1(arma::mat& g3, int lk, double gam, double om) {
+//    int Nmin=0;
+//    for(int n1=0; n1<lk; n1++) {
+//	for(int n2=0; n2<lk; n2++) {
+//	    Nmin = std::min(n1, n2);
+//	    for(int c=0; c<=Nmin; c++) {
+//		g3.at(n1, n2) += exp(Rf_dbinom(c, n1, om, true) +
+//				  Rf_dpois(n2-c, gam, true));
+//	    }
+//	}
+//    }
+//}
+void tp1(arma::mat& g3, int nrI, int nrI1, Rcpp::IntegerVector N, arma::imat I, arma::imat I1, Rcpp::List Ib, Rcpp::List Ip, double gam, double om) {
+  Rcpp::NumericVector pois1 = dpois(N, gam, true);
+  arma::vec pois = as<arma::vec>(pois1);
+  arma::vec bin = arma::zeros<arma::vec>(nrI1);
+  for(int i=0; i<nrI1; i++) {
+    bin(i) = Rf_dbinom(I1(i,0), I1(i,1), om, true);
+  }
+  for(int s=0; s<nrI; s++) {
+    arma::uvec indB = as<arma::uvec>(Ib[s]);
+    arma::uvec indP = as<arma::uvec>(Ip[s]);
+    int nc = indB.n_elem;
+    for(int q=0; q<nc; q++) {
+      g3(s) += exp(bin(indB(q)) + pois(indP(q)));
     }
+  }
 }
 
 
@@ -39,7 +55,11 @@ void tp2(arma::mat& g3, int lk, double gam, double om) {
 
 
 
-// trend model
+
+
+
+
+// trend model (exponential growth)
 void tp3(arma::mat& g3, int lk, double gam) {
     for(int n1=0; n1<lk; n1++) {
 	for(int n2=0; n2<lk; n2++) {
@@ -51,8 +71,10 @@ void tp3(arma::mat& g3, int lk, double gam) {
 
 
 
-SEXP nll_pcountOpen( SEXP y_, SEXP Xlam_, SEXP Xgam_, SEXP Xom_, SEXP Xp_, SEXP beta_lam_, SEXP beta_gam_, SEXP beta_om_, SEXP beta_p_, SEXP log_alpha_, SEXP Xlam_offset_, SEXP Xgam_offset_, SEXP Xom_offset_, SEXP Xp_offset_, SEXP ytna_, SEXP yna_, SEXP lk_, SEXP mixture_, SEXP first_, SEXP last_, SEXP M_, SEXP J_, SEXP T_, SEXP delta_, SEXP dynamics_, SEXP fix_, SEXP go_dims_) {
+
+SEXP nll_pcountOpen( SEXP y_, SEXP Xlam_, SEXP Xgam_, SEXP Xom_, SEXP Xp_, SEXP beta_lam_, SEXP beta_gam_, SEXP beta_om_, SEXP beta_p_, SEXP log_alpha_, SEXP Xlam_offset_, SEXP Xgam_offset_, SEXP Xom_offset_, SEXP Xp_offset_, SEXP ytna_, SEXP yna_, SEXP lk_, SEXP mixture_, SEXP first_, SEXP last_, SEXP M_, SEXP J_, SEXP T_, SEXP delta_, SEXP dynamics_, SEXP fix_, SEXP go_dims_, SEXP I_, SEXP I1_, SEXP Ib_, SEXP Ip_) {
   int lk = as<int>(lk_);
+  Rcpp::IntegerVector N = seq_len(lk)-1;
   int M = as<int>(M_);
   int J = as<int>(J_);
   int T = as<int>(T_);
@@ -74,6 +96,12 @@ SEXP nll_pcountOpen( SEXP y_, SEXP Xlam_, SEXP Xgam_, SEXP Xom_, SEXP Xp_, SEXP
   std::string dynamics = as<std::string>(dynamics_);
   std::string fix = as<std::string>(fix_);
   std::string go_dims = as<std::string>(go_dims_);
+  arma::imat I = as<arma::imat>(I_);
+  arma::imat I1 = as<arma::imat>(I1_);
+  Rcpp::List Ib(Ib_);
+  Rcpp::List Ip(Ip_);
+  int nrI = I.n_rows;
+  int nrI1 = I1.n_rows;
   double alpha=0.0, psi=0.0;
   if(mixture=="NB")
     alpha = exp(log_alpha);
@@ -104,8 +132,8 @@ SEXP nll_pcountOpen( SEXP y_, SEXP Xlam_, SEXP Xgam_, SEXP Xom_, SEXP Xp_, SEXP
   }
   arma::colvec pv = 1.0/(1.0+exp(-1*(Xp*beta_p + Xp_offset)));
   pv.reshape(J*T, M);
-  arma::mat pm = trans(pv); // this might not give correct order
-  // format matrices as cubes
+  arma::mat pm = trans(pv);
+  // format matrices as cubes (would be faster to avoid this)
   arma::icube y(M,J,T);
   arma::cube p(M,J,T);
   arma::icube yna(M,J,T);
@@ -131,10 +159,13 @@ SEXP nll_pcountOpen( SEXP y_, SEXP Xlam_, SEXP Xgam_, SEXP Xom_, SEXP Xp_, SEXP
   arma::cube g3_t = arma::zeros<arma::cube>(lk,lk,T-1);
   // compute g3 is there are no covariates of omega/gamma
   if(go_dims == "scalar") {
-    if(dynamics=="constant" || dynamics=="notrend")
-      tp1(g3, lk, gam(0,first[0]-1), om(0,first[0]-1));
-    else if(dynamics=="autoreg")
+    if(dynamics=="constant" || dynamics=="notrend") {
+      //      tp1(g3, lk, gam(0,first[0]-1), om(0,first[0]-1));
+      tp1(g3, nrI, nrI1, N, I, I1, Ib, Ip, gam(0,first[0]-1), om(0,first[0]-1));
+    }
+    else if(dynamics=="autoreg") {
       tp2(g3, lk, gam(0,first[0]-1), om(0,first[0]-1));
+    }
     else if(dynamics=="trend")
       tp3(g3, lk, gam(0,first[0]-1));
   } else if(go_dims == "rowvec") {
@@ -148,10 +179,13 @@ SEXP nll_pcountOpen( SEXP y_, SEXP Xlam_, SEXP Xgam_, SEXP Xom_, SEXP Xp_, SEXP
       if(ytna(first1,t)==1) { // FIXME: this is not generic!
 	continue;
       }
-      if(dynamics=="constant" || dynamics=="notrend")
-	tp1(g3_t.slice(t), lk, gam(first1,t), om(first1,t));
-      else if(dynamics=="autoreg")
+      if(dynamics=="constant" || dynamics=="notrend") {
+	//	tp1(g3_t.slice(t), lk, gam(first1,t), om(first1,t));
+	tp1(g3_t.slice(t), nrI, nrI1, N, I, I1, Ib, Ip, gam(first1,t), om(first1,t));
+      }
+      else if(dynamics=="autoreg") {
 	tp2(g3_t.slice(t), lk, gam(first1,t), om(first1,t));
+    }
       else if(dynamics=="trend")
 	tp3(g3_t.slice(t), lk, gam(first1,t));
     }
@@ -181,10 +215,13 @@ SEXP nll_pcountOpen( SEXP y_, SEXP Xlam_, SEXP Xgam_, SEXP Xom_, SEXP Xp_, SEXP
 	// computes transition probs for g3
 	if(go_dims == "matrix") {
 	  g3.zeros();
-	  if(dynamics=="constant" || dynamics=="notrend")
-	    tp1(g3, lk, gam(i,t-1), om(i,t-1));
-	  else if(dynamics=="autoreg")
+	  if(dynamics=="constant" || dynamics=="notrend") {
+	    //	    tp1(g3, lk, gam(i,t-1), om(i,t-1));
+	    tp1(g3, nrI, nrI1, N, I, I1, Ib, Ip, gam(i,t-1), om(i,t-1));
+	  }
+	  else if(dynamics=="autoreg") {
 	    tp2(g3, lk, gam(i,t-1), om(i,t-1));
+	  }
 	  else if(dynamics=="trend")
 	    tp3(g3, lk, gam(i,t-1));
 	} else if(go_dims == "rowvec") {
@@ -195,17 +232,7 @@ SEXP nll_pcountOpen( SEXP y_, SEXP Xlam_, SEXP Xgam_, SEXP Xom_, SEXP Xp_, SEXP
 	if(delta_it>1) {
 	  g3_d = g3;
 	  for(int d=1; d<delta_it; d++) {
-	    //	    g3_d *= g3_d; // ouch bad bug
 	    g3_d = g3_d * g3;
-	    /*
-	    might be necessary to guard against underflow
-	    approach 1
-	    arma::mat cs1 = sum(g3, 0);
-	    arma::mat csm1 = arma::repmat(cs1, n, 1);
-	    g3 = g3 / csm1
-	    approach 2
-	    replace values outside [0,1]
-	    */
 	    }
 	  g_star = g3_d * g1_t_star;
 	} else
@@ -236,7 +263,6 @@ SEXP nll_pcountOpen( SEXP y_, SEXP Xlam_, SEXP Xgam_, SEXP Xom_, SEXP Xp_, SEXP
     if(delta_i0>1) {
       g3_d = g3;
       for(int d=0; d<delta_i0; d++) {
-	//	g3_d *= g3_d; // same bug as above
 	g3_d = g3_d * g3;
       }
       g_star = g3_d * g1_star;
